@@ -27,11 +27,8 @@ def convert_from_env(env: UnityPy.Environment, output_dir: Path, show_warnings:
             case "MonoBehaviour":
                 if resource.serialized_type.nodes:
                     tree = resource.read_typetree()
-                    if tree["m_Name"] and not tree["m_Name"].isspace():
-                        target_path = Path(target_path, tree["m_Name"])
-                    else:
+                    if not tree["m_Name"] or tree["m_Name"].isspace():
                         target_path = Path(output_dir, str(resource.path_id))
-                    
                     target_path.parent.mkdir(parents=True, exist_ok=True)
                     with open(target_path.with_suffix(".json"), "w", encoding="utf8") as f:
                         json.dump(tree, f, ensure_ascii=False, indent=4)
